'use client'

import { useEffect, useState } from 'react'
import { useSession } from 'next-auth/react'
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from '@/components/ui/card'

interface Ticket {
  id: string
  eventName: string
  price: number
  createdAt: string
  used: boolean
}

export default function UserTickets() {
  const { data: session } = useSession()
  const [tickets, setTickets] = useState<Ticket[]>([])

  useEffect(() => {
    if (session) {
      fetch('/api/tickets')
        .then(response => response.json())
        .then(data => setTickets(data))
        .catch(error => console.error('Error fetching tickets:', error))
    }
  }, [session])

  if (!session) {
    return null
  }

  return (
    <div className="w-full max-w-2xl mt-8">
      <h2 className="text-2xl font-bold mb-4">Your Tickets</h2>
      {tickets.map(ticket => (
        <Card key={ticket.id} className="mb-4">
          <CardHeader>
            <CardTitle>{ticket.eventName}</CardTitle>
            <CardDescription>Purchased on {new Date(ticket.createdAt).toLocaleDateString()}</CardDescription>
          </CardHeader>
          <CardContent>
            <p>Price: ${ticket.price}</p>
            <p>Status: {ticket.used ? 'Used' : 'Valid'}</p>
          </CardContent>
        </Card>
      ))}
    </div>
  )
}

